Type: Package
Package: GenomeAdmixR
Title: Simulate Admixture of Genomes
Version: 2.1.13.2
Authors@R: 
    c(person(given = "Thijs",
             family = "Janzen",
             role = c("aut", "cre"),
             email = "thijsjanzen@gmail.com"),
      person(given = "Fernando",
             family = "Diaz G.",
             role = "ctb",
             email = "ferdiazfer@gmail.com"),
      person(given = "Richèl J.C.",
             family = "Bilderbeek",
             role = "ctb"))
Description: Individual-based simulations forward in time,
    simulating how patterns in ancestry along the genome change after
    admixture. Full description can be found in Janzen (2021)
    <doi:10.1111/2041-210X.13612>.
License: GPL (>= 2)
URL: https://github.com/thijsjanzen/GenomeAdmixR
BugReports: https://github.com/thijsjanzen/GenomeAdmixR/issues
Imports: ggplot2, ggridges, hierfstat, Rcpp, RcppParallel, rlang,
        stringr, tibble, vcfR
Suggests: dplyr, junctions, knitr, magrittr, rmarkdown, testit,
        testthat, pbapply
LinkingTo: Rcpp, RcppArmadillo, RcppParallel
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 2.10)
SystemRequirements: C++17
NeedsCompilation: yes
Packaged: 2026-05-13 15:19:33 UTC; thijsjanzen
Author: Thijs Janzen [aut, cre],
  Fernando Diaz G. [ctb],
  Richèl J.C. Bilderbeek [ctb]
Maintainer: Thijs Janzen <thijsjanzen@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-14 14:10:28 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-14 15:02:07 UTC; unix
Archs: GenomeAdmixR.so.dSYM
