# Generated by roxygen2: do not edit by hand

S3method(plot,individual)
S3method(print,genomeadmixr_data)
S3method(print,individual)
S3method(print,population)
export(ancestry_module)
export(calculate_allele_frequencies)
export(calculate_average_ld)
export(calculate_dist_junctions)
export(calculate_fst)
export(calculate_heterozygosity)
export(calculate_ld)
export(calculate_marker_frequency)
export(combine_input_data)
export(create_artificial_genomeadmixr_data)
export(create_iso_female)
export(default_params_doc)
export(iso_female_ancestry)
export(iso_female_sequence)
export(load_population)
export(migration_settings)
export(plink_to_genomeadmixr_data)
export(plot_chromosome)
export(plot_difference_frequencies)
export(plot_dist_junctions)
export(plot_frequencies)
export(plot_joyplot_frequencies)
export(plot_over_time)
export(plot_start_end)
export(read_input_data)
export(save_population)
export(sequence_module)
export(simulate_admixture)
export(simulate_ancestry_migration)
export(simulate_sequence_migration)
export(simulation_data_to_genomeadmixr_data)
export(vcfR_to_genomeadmixr_data)
export(write_as_plink)
import(Rcpp)
importFrom(RcppParallel, RcppParallelLibs)
importFrom(rlang,.data)
useDynLib(GenomeAdmixR, .registration = TRUE)
